==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZestawienieWinienMaPozycja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZestawienieWinienMaPozycja extends GenericDPSObject {
    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mieszkaniecId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.POPRZEDNIA_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long poprzedniaPozycjaId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ZESTAWIENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zestawienieId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.DATA_GENEROWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataGenerowania;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WINIEN_SK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaWinienSk;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_MA_SK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaMaSk;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ODPISY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaOdpisy;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_PRZYPISY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaPrzypisy;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WPLATY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaWplaty;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ZWROTY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaZwroty;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.MIESZKANIEC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.POPRZEDNIA_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPoprzedniaPozycjaId() {
        return poprzedniaPozycjaId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.POPRZEDNIA_POZYCJA_ID
     *
     * @param poprzedniaPozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoprzedniaPozycjaId(Long poprzedniaPozycjaId) {
        this.poprzedniaPozycjaId = poprzedniaPozycjaId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.ZESTAWIENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZestawienieId() {
        return zestawienieId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ZESTAWIENIE_ID
     *
     * @param zestawienieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZestawienieId(Long zestawienieId) {
        this.zestawienieId = zestawienieId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.DATA_GENEROWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataGenerowania() {
        return dataGenerowania;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.DATA_GENEROWANIA
     *
     * @param dataGenerowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataGenerowania(Date dataGenerowania) {
        this.dataGenerowania = dataGenerowania;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WINIEN_SK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaWinienSk() {
        return kwotaWinienSk;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WINIEN_SK
     *
     * @param kwotaWinienSk
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaWinienSk(BigDecimal kwotaWinienSk) {
        this.kwotaWinienSk = kwotaWinienSk;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_MA_SK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaMaSk() {
        return kwotaMaSk;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_MA_SK
     *
     * @param kwotaMaSk
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaMaSk(BigDecimal kwotaMaSk) {
        this.kwotaMaSk = kwotaMaSk;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ODPISY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaOdpisy() {
        return kwotaOdpisy;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ODPISY
     *
     * @param kwotaOdpisy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaOdpisy(BigDecimal kwotaOdpisy) {
        this.kwotaOdpisy = kwotaOdpisy;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_PRZYPISY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaPrzypisy() {
        return kwotaPrzypisy;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_PRZYPISY
     *
     * @param kwotaPrzypisy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaPrzypisy(BigDecimal kwotaPrzypisy) {
        this.kwotaPrzypisy = kwotaPrzypisy;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WPLATY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaWplaty() {
        return kwotaWplaty;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WPLATY
     *
     * @param kwotaWplaty
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaWplaty(BigDecimal kwotaWplaty) {
        this.kwotaWplaty = kwotaWplaty;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ZWROTY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaZwroty() {
        return kwotaZwroty;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ZWROTY
     *
     * @param kwotaZwroty
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaZwroty(BigDecimal kwotaZwroty) {
        this.kwotaZwroty = kwotaZwroty;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZestawienieWinienMaPozycja other = (ZestawienieWinienMaPozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getPoprzedniaPozycjaId() == null ? other.getPoprzedniaPozycjaId() == null : this.getPoprzedniaPozycjaId().equals(other.getPoprzedniaPozycjaId()))
            && (this.getZestawienieId() == null ? other.getZestawienieId() == null : this.getZestawienieId().equals(other.getZestawienieId()))
            && (this.getDataGenerowania() == null ? other.getDataGenerowania() == null : this.getDataGenerowania().equals(other.getDataGenerowania()))
            && (this.getKwotaWinienSk() == null ? other.getKwotaWinienSk() == null : this.getKwotaWinienSk().equals(other.getKwotaWinienSk()))
            && (this.getKwotaMaSk() == null ? other.getKwotaMaSk() == null : this.getKwotaMaSk().equals(other.getKwotaMaSk()))
            && (this.getKwotaOdpisy() == null ? other.getKwotaOdpisy() == null : this.getKwotaOdpisy().equals(other.getKwotaOdpisy()))
            && (this.getKwotaPrzypisy() == null ? other.getKwotaPrzypisy() == null : this.getKwotaPrzypisy().equals(other.getKwotaPrzypisy()))
            && (this.getKwotaWplaty() == null ? other.getKwotaWplaty() == null : this.getKwotaWplaty().equals(other.getKwotaWplaty()))
            && (this.getKwotaZwroty() == null ? other.getKwotaZwroty() == null : this.getKwotaZwroty().equals(other.getKwotaZwroty()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getPoprzedniaPozycjaId() == null) ? 0 : getPoprzedniaPozycjaId().hashCode());
        result = prime * result + ((getZestawienieId() == null) ? 0 : getZestawienieId().hashCode());
        result = prime * result + ((getDataGenerowania() == null) ? 0 : getDataGenerowania().hashCode());
        result = prime * result + ((getKwotaWinienSk() == null) ? 0 : getKwotaWinienSk().hashCode());
        result = prime * result + ((getKwotaMaSk() == null) ? 0 : getKwotaMaSk().hashCode());
        result = prime * result + ((getKwotaOdpisy() == null) ? 0 : getKwotaOdpisy().hashCode());
        result = prime * result + ((getKwotaPrzypisy() == null) ? 0 : getKwotaPrzypisy().hashCode());
        result = prime * result + ((getKwotaWplaty() == null) ? 0 : getKwotaWplaty().hashCode());
        result = prime * result + ((getKwotaZwroty() == null) ? 0 : getKwotaZwroty().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", poprzedniaPozycjaId=").append(poprzedniaPozycjaId);
        sb.append(", zestawienieId=").append(zestawienieId);
        sb.append(", dataGenerowania=").append(dataGenerowania);
        sb.append(", kwotaWinienSk=").append(kwotaWinienSk);
        sb.append(", kwotaMaSk=").append(kwotaMaSk);
        sb.append(", kwotaOdpisy=").append(kwotaOdpisy);
        sb.append(", kwotaPrzypisy=").append(kwotaPrzypisy);
        sb.append(", kwotaWplaty=").append(kwotaWplaty);
        sb.append(", kwotaZwroty=").append(kwotaZwroty);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZestawienieWinienMaPozycja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZestawienieWinienMaPozycja extends GenericDPSObject {
    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mieszkaniecId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.POPRZEDNIA_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long poprzedniaPozycjaId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ZESTAWIENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zestawienieId;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.DATA_GENEROWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataGenerowania;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WINIEN_SK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaWinienSk;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_MA_SK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaMaSk;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ODPISY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaOdpisy;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_PRZYPISY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaPrzypisy;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WPLATY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaWplaty;

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ZWROTY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaZwroty;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.MIESZKANIEC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.POPRZEDNIA_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPoprzedniaPozycjaId() {
        return poprzedniaPozycjaId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.POPRZEDNIA_POZYCJA_ID
     *
     * @param poprzedniaPozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoprzedniaPozycjaId(Long poprzedniaPozycjaId) {
        this.poprzedniaPozycjaId = poprzedniaPozycjaId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.ZESTAWIENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZestawienieId() {
        return zestawienieId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.ZESTAWIENIE_ID
     *
     * @param zestawienieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZestawienieId(Long zestawienieId) {
        this.zestawienieId = zestawienieId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.DATA_GENEROWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataGenerowania() {
        return dataGenerowania;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.DATA_GENEROWANIA
     *
     * @param dataGenerowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataGenerowania(Date dataGenerowania) {
        this.dataGenerowania = dataGenerowania;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WINIEN_SK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaWinienSk() {
        return kwotaWinienSk;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WINIEN_SK
     *
     * @param kwotaWinienSk
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaWinienSk(BigDecimal kwotaWinienSk) {
        this.kwotaWinienSk = kwotaWinienSk;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_MA_SK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaMaSk() {
        return kwotaMaSk;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_MA_SK
     *
     * @param kwotaMaSk
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaMaSk(BigDecimal kwotaMaSk) {
        this.kwotaMaSk = kwotaMaSk;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ODPISY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaOdpisy() {
        return kwotaOdpisy;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ODPISY
     *
     * @param kwotaOdpisy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaOdpisy(BigDecimal kwotaOdpisy) {
        this.kwotaOdpisy = kwotaOdpisy;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_PRZYPISY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaPrzypisy() {
        return kwotaPrzypisy;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_PRZYPISY
     *
     * @param kwotaPrzypisy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaPrzypisy(BigDecimal kwotaPrzypisy) {
        this.kwotaPrzypisy = kwotaPrzypisy;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WPLATY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaWplaty() {
        return kwotaWplaty;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_WPLATY
     *
     * @param kwotaWplaty
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaWplaty(BigDecimal kwotaWplaty) {
        this.kwotaWplaty = kwotaWplaty;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ZWROTY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaZwroty() {
        return kwotaZwroty;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA_POZYCJA.KWOTA_ZWROTY
     *
     * @param kwotaZwroty
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaZwroty(BigDecimal kwotaZwroty) {
        this.kwotaZwroty = kwotaZwroty;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZestawienieWinienMaPozycja other = (ZestawienieWinienMaPozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getPoprzedniaPozycjaId() == null ? other.getPoprzedniaPozycjaId() == null : this.getPoprzedniaPozycjaId().equals(other.getPoprzedniaPozycjaId()))
            && (this.getZestawienieId() == null ? other.getZestawienieId() == null : this.getZestawienieId().equals(other.getZestawienieId()))
            && (this.getDataGenerowania() == null ? other.getDataGenerowania() == null : this.getDataGenerowania().equals(other.getDataGenerowania()))
            && (this.getKwotaWinienSk() == null ? other.getKwotaWinienSk() == null : this.getKwotaWinienSk().equals(other.getKwotaWinienSk()))
            && (this.getKwotaMaSk() == null ? other.getKwotaMaSk() == null : this.getKwotaMaSk().equals(other.getKwotaMaSk()))
            && (this.getKwotaOdpisy() == null ? other.getKwotaOdpisy() == null : this.getKwotaOdpisy().equals(other.getKwotaOdpisy()))
            && (this.getKwotaPrzypisy() == null ? other.getKwotaPrzypisy() == null : this.getKwotaPrzypisy().equals(other.getKwotaPrzypisy()))
            && (this.getKwotaWplaty() == null ? other.getKwotaWplaty() == null : this.getKwotaWplaty().equals(other.getKwotaWplaty()))
            && (this.getKwotaZwroty() == null ? other.getKwotaZwroty() == null : this.getKwotaZwroty().equals(other.getKwotaZwroty()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getPoprzedniaPozycjaId() == null) ? 0 : getPoprzedniaPozycjaId().hashCode());
        result = prime * result + ((getZestawienieId() == null) ? 0 : getZestawienieId().hashCode());
        result = prime * result + ((getDataGenerowania() == null) ? 0 : getDataGenerowania().hashCode());
        result = prime * result + ((getKwotaWinienSk() == null) ? 0 : getKwotaWinienSk().hashCode());
        result = prime * result + ((getKwotaMaSk() == null) ? 0 : getKwotaMaSk().hashCode());
        result = prime * result + ((getKwotaOdpisy() == null) ? 0 : getKwotaOdpisy().hashCode());
        result = prime * result + ((getKwotaPrzypisy() == null) ? 0 : getKwotaPrzypisy().hashCode());
        result = prime * result + ((getKwotaWplaty() == null) ? 0 : getKwotaWplaty().hashCode());
        result = prime * result + ((getKwotaZwroty() == null) ? 0 : getKwotaZwroty().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", poprzedniaPozycjaId=").append(poprzedniaPozycjaId);
        sb.append(", zestawienieId=").append(zestawienieId);
        sb.append(", dataGenerowania=").append(dataGenerowania);
        sb.append(", kwotaWinienSk=").append(kwotaWinienSk);
        sb.append(", kwotaMaSk=").append(kwotaMaSk);
        sb.append(", kwotaOdpisy=").append(kwotaOdpisy);
        sb.append(", kwotaPrzypisy=").append(kwotaPrzypisy);
        sb.append(", kwotaWplaty=").append(kwotaWplaty);
        sb.append(", kwotaZwroty=").append(kwotaZwroty);
        sb.append("]");
        return sb.toString();
    }
}
